summaryrefslogtreecommitdiffstats
path: root/net/ocsp/nss_ocsp.h
diff options
context:
space:
mode:
Diffstat (limited to 'net/ocsp/nss_ocsp.h')
-rw-r--r--net/ocsp/nss_ocsp.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/net/ocsp/nss_ocsp.h b/net/ocsp/nss_ocsp.h
index 97d69b9..cf2e66e 100644
--- a/net/ocsp/nss_ocsp.h
+++ b/net/ocsp/nss_ocsp.h
@@ -17,9 +17,13 @@ void SetMessageLoopForOCSP();
// Initializes OCSP handlers for NSS. This must be called before any
// certificate verification functions. This function is thread-safe, and OCSP
// handlers will only ever be initialized once.
void EnsureOCSPInit();
+// This should be called once on shutdown to stop issuing URLRequests for OCSP.
+void ShutdownOCSP();
+
// Set URLRequestContext for OCSP handlers.
void SetURLRequestContextForOCSP(URLRequestContext* request_context);
URLRequestContext* GetURLRequestContextForOCSP();
@@ -17,9 +17,13 @@ void SetMessageLoopForOCSP();
// Initializes OCSP handlers for NSS. This must be called before any
// certificate verification functions. This function is thread-safe, and OCSP
-// handlers will only ever be initialized once.
+// handlers will only ever be initialized once. ShutdownOCSP() must be called
+// on shutdown.
void EnsureOCSPInit();